---

slug: /json-formatted-data-types
---

# Overview of JSON data types

seekdb supports the JavaScript Object Notation (JSON) data type in compliance with the RFC 7159 standard. You can use it to store semi-structured JSON data and access or modify the data within JSON documents.

The JSON data type offers the following advantages:

* **Automatic validation**: JSON documents stored in JSON columns are automatically validated. Invalid documents will trigger an error.

* **Optimized storage format**: JSON documents stored in JSON columns are converted into an optimized format that enables fast reading and access. When the server reads a JSON value stored in binary format, it doesn't need to parse the value from text.

* **Semi-structured encoding**: This feature further reduces storage costs by splitting a JSON document into multiple sub-columns, with each sub-column encoded individually. This improves compression rates and reduces the storage space required for JSON data. For more information, see [Create a JSON value](200.create-a-json-value.md) and [Semi-structured encoding](600.json-semi-struct.md).

## References

* [Overview of JSON functions](https://en.oceanbase.com/docs/common-oceanbase-database-10000000001974794)